summaryrefslogtreecommitdiff
path: root/include/llvm/MC/MCAsmInfo.h
diff options
context:
space:
mode:
authorRafael Espindola <rafael.espindola@gmail.com>2011-05-04 17:44:06 +0000
committerRafael Espindola <rafael.espindola@gmail.com>2011-05-04 17:44:06 +0000
commit597a7664e1bbe2ea5f757eb6e853bd1d2fe98d6c (patch)
treeab0e95677135ee8017c47e482d1a47d95500509d /include/llvm/MC/MCAsmInfo.h
parent91266017705c13496e062208d1ad7a4c39b20220 (diff)
downloadllvm-597a7664e1bbe2ea5f757eb6e853bd1d2fe98d6c.tar.gz
llvm-597a7664e1bbe2ea5f757eb6e853bd1d2fe98d6c.tar.bz2
llvm-597a7664e1bbe2ea5f757eb6e853bd1d2fe98d6c.tar.xz
Producing a DW_FORM_addr for DW_AT_stmt_list is probably correct, but
it is both inefficient and unexpected by dwarfdump. Change to a DW_FORM_data4. While in here, change the predicate name to reflect that the position is not really absolute (it is an offset), just that the linker needs a relocation. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@130846 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/llvm/MC/MCAsmInfo.h')
-rw-r--r--include/llvm/MC/MCAsmInfo.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/llvm/MC/MCAsmInfo.h b/include/llvm/MC/MCAsmInfo.h
index 8733161394..2ed5c0a47a 100644
--- a/include/llvm/MC/MCAsmInfo.h
+++ b/include/llvm/MC/MCAsmInfo.h
@@ -279,9 +279,9 @@ namespace llvm {
/// DwarfSectionOffsetDirective - Special section offset directive.
const char* DwarfSectionOffsetDirective; // Defaults to NULL
- /// DwarfUsesAbsoluteLabelForStmtList - True if DW_AT_stmt_list needs
- /// absolute label instead of offset.
- bool DwarfUsesAbsoluteLabelForStmtList; // Defaults to true;
+ /// DwarfRequiresRelocationForStmtList - True if DW_AT_stmt_list needs
+ /// a relocation to the correct offset.
+ bool DwarfRequiresRelocationForStmtList; // Defaults to true;
// DwarfUsesLabelOffsetDifference - True if Dwarf2 output can
// use EmitLabelOffsetDifference.
@@ -476,8 +476,8 @@ namespace llvm {
const char *getDwarfSectionOffsetDirective() const {
return DwarfSectionOffsetDirective;
}
- bool doesDwarfUsesAbsoluteLabelForStmtList() const {
- return DwarfUsesAbsoluteLabelForStmtList;
+ bool doesDwarfRequireRelocationForStmtList() const {
+ return DwarfRequiresRelocationForStmtList;
}
bool doesDwarfUsesLabelOffsetForRanges() const {
return DwarfUsesLabelOffsetForRanges;